@@ -2,6 +2,10 @@
 for nanomaterials like the non-adiabatic coupling vectors (NACV) using several quantum \
 chemical (QM) packages."""
 
+from ._version import __version__ as __version__
+from ._version_info import version_info as version_info
+from ._logger import logger as logger
+
 from .analysis import (
     autocorrelate, dephasing, convolute, func_conv, gauss_function,
     parse_list_of_lists, read_couplings, read_energies,
